@@ -12,7 +12,7 @@ def thumb_querie(id:int) -> typing.Union[tuple, str]:
         cursor = connection.cursor()
         select_command = f"SELECT * FROM picturereference WHERE id={int(id)};"
         cursor.execute(select_command)
-        pic_ref = cursor.fetchone()[0]
+        pic_ref = cursor.fetchone()
     except Exception as e:
         return e
     finally:
